flailwind library

Tailwind-like styling in Flutter with text styles and colors.

Classes

TextStyleWithContext
@template text_style_with_context A TextStyle that has a BuildContext as a property to be used in composing styles. @endtemplate

Extensions

TextStyleHelper on TextStyleWithContext?
Extension methods for TextStyleWithContext.
ThemeContextExtension on BuildContext
Theme-based extension methods for BuildContext.
WidgetStatePropertyColor on T
A property that can be used to set a color for a widget.